package server

import (
	"strconv"

	"github.com/ethereum/go-ethereum/common/hexutil"
	"github.com/gin-gonic/gin"
)

func getClaimed(c *gin.Context) {
	address := c.Query("address")

	if _, err := hexutil.Decode(address); err != nil || len(address) != 42 {
		c.JSON(200, withError("invalid params"))
		return
	}

	resp, err := srv.GetClaimed(address)
	if err != nil {
		c.JSON(200, withError("internal error"))
		return
	}

	c.JSON(200, withSuccess(resp))
}

func getRecord(c *gin.Context) {
	address := c.Query("address")

	if _, err := hexutil.Decode(address); err != nil || len(address) != 42 {
		c.JSON(200, withError("invalid params"))
		return
	}

	pageSize, _ := strconv.Atoi(c.Query("pageSize"))
	if pageSize > 100 || pageSize < 1 { // 默认每页100条
		pageSize = 100
	}
	page, _ := strconv.Atoi(c.Query("page"))
	if page < 1 {
		page = 1
	}

	resp, err := srv.GetRecord(address, page, pageSize)
	if err != nil {
		c.JSON(200, withError("internal error"))
		return
	}

	c.JSON(200, withSuccess(resp))
}

func withSuccess(data interface{}) interface{} {
	return map[string]interface{}{
		"code": 0,
		"msg":  "ok",
		"data": data,
	}
}

func withError(msg string) interface{} {
	return map[string]interface{}{
		"code":  1,
		"msg":   "",
		"error": msg,
	}
}
